@@ -53,7 +53,7 @@ BEGIN {
                         $first_form
                       );
     $PACKAGE      = __PACKAGE__;
-    $VERSION        = q(0.48);
+    $VERSION        = q(0.49);
     @VARS         = qw( 
                         $VERSION
                         $AUTHOR
@@ -173,8 +173,8 @@ sub Write_to_File {
         open SUBCLASS,     ">$filename" or 
             die "error $me -can't open file '$filename' for output";
         UI->autoflush(1);
-        SUBCLASS->autoflush(1);
         SIGS->autoflush(1);
+        SUBCLASS->autoflush(1);
     } else {
         # Nothing to do
     }
@@ -218,20 +218,21 @@ sub warning {
 
     } else {
         return"#
-# DO NOT EDIT THIS FILE, any changes that you make will be lost when
-# the file is overwritten by the next run of $class
+# DO NOT EDIT THIS FILE, ANY CHANGES THAT YOU MAKE WILL BE LOST WHEN
+# THE FILE IS OVERWRITTEN BY THE NEXT RUN OF $class
 #
 ";
     }
 }
 
-sub perl_UI_preamble {
+sub perl_preamble {
     my ($class, $package, $project, $proto, $name, $oktoedit) = @_;
     my $localtime = localtime;
     my $warning_string;
     return 
-"#==============================================================================
-#=== This is the '$name' UI construction class                              
+"
+#==============================================================================
+#=== This is the '$name' class                              
 #==============================================================================
 package $name;
 require 5.000; use strict \'vars\', \'refs\', \'subs\';
@@ -258,6 +259,11 @@ $project->{'copying'} $project->{'author'}
 sub perl_about {
     my ($class, $project, $name) = @_;
 #use Data::Dumper;print Dumper($project);
+    my $logo = "\$Glade::PerlRun::pixmaps_directory";
+#    my $logo = $project->{'glade_proto'}{'project'}{'pixmaps_directory'};
+    $logo .= '/' if $logo;
+    $logo .= $project->{'logo'};
+
     if ($main::Glade_Perl_Generate_options->{'allow_gnome'}) {
         return
 "sub about_Form {
@@ -279,9 +285,9 @@ ${indent}${indent}\"Gtk version:        \$gtkversion\\n\".
 ${indent}${indent}\"Gtk-Perl version:    \$Gtk::VERSION\\n\".
 ${indent}${indent}\"run from file:        \$name\\n\".
 ${indent}${indent}\"$project->{'copying'}\", 
-${indent}${indent}\"$project->{'logo_filename'}\", 
+${indent}${indent}\"$logo\", 
 ${indent});
-${indent}\$ab->set_title(\"About $project->{'name'}\" );
+${indent}\$ab->set_title(\"About $name\" );
 ${indent}\$ab->position('mouse' );
 ${indent}\$ab->set_policy(1, 1, 0 );
 ${indent}\$ab->set_modal(1 );
@@ -301,14 +307,61 @@ ${indent}${indent}__PACKAGE__.\" (version $project->{'version'} - $project->{'da
 ${indent}${indent}\"Written by         $project->{'author'} \\n\\n\".
 ${indent}${indent}\"$project->{'description'} \\n\\n\".
 ${indent}${indent}\"Gtk version:        \$gtkversion\\n\".
-${indent}${indent}\"Gtk-Perl version:    \$Gtk::VERSION\\n\\n\".
+${indent}${indent}\"Gtk-Perl version:    \$Gtk::VERSION\\n\".
 ${indent}${indent}\"run from file:        \$name\";
 ${indent}__PACKAGE__->message_box(\$message, \"About \\u\".__PACKAGE__, ['Dismiss', 'Quit Program'], 1,
-${indent}${indent}'$project->{'logo_filename'}', 'left' );
+${indent}${indent}\"$logo\", 'left' );
 }";
     }
 }
 
+sub perl_signal_handler {
+    my ($class, $handler, $type) = @_;
+    my ($body);
+    if ($type eq 'SIGS') {
+        $body = "
+${indent}my (\$class, \$data, \$object, \$instance, \$event) = \@_;
+${indent}my \$me = __PACKAGE__.\"->$handler\";
+${indent}# Get ref to hash of all widgets on our form
+${indent}my \$form = \$__PACKAGE__::all_forms->{\$instance};
+
+${indent}# REPLACE the line below with the actions to be taken when ".
+    "__PACKAGE__.\"->$handler.\" is called
+${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
+    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$glade2perl->{'logo'}\");
+
+";
+    } elsif ($type eq 'SUBCLASS') {
+        $body = "
+${indent}my (\$class, \$data, \$object, \$instance, \$event) = \@_;
+${indent}my \$me = __PACKAGE__.\"->$handler\";
+${indent}# Get ref to hash of all widgets on our form
+${indent}my \$form = \$__PACKAGE__::all_forms->{\$instance};
+
+${indent}# REPLACE the line below with the actions to be taken when ".
+    "__PACKAGE__.\"->$handler.\" is called
+#${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
+    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$glade2perl->{'logo'}\");
+${indent}shift->SUPER::$handler(\@_);
+
+";
+    } elsif ($type eq 'Libglade') {
+        $body = "
+${indent}my (\$class, \$data, \$event) = \@_;
+${indent}my \$me = __PACKAGE__.\"->$handler\";
+
+${indent}# REPLACE the line below with the actions to be taken when ".
+    "__PACKAGE__.\"->$handler.\" is called
+${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
+    "__PACKAGE__, \"\$Glade::PerlRun::pixmaps_directory/$glade2perl->{'logo'}\");
+
+";
+    }
+
+    return "sub $handler {$body} # End of sub $handler
+";
+}
+
 sub perl_constructor_bottom {
     my ($class, $project, $formname) = @_;
     my $about_string = $class->perl_about($project, $project->{'name'});
@@ -320,6 +373,8 @@ ${indent}bless \$self, \$class;
 ${indent}\$self->FORM(\$forms->{'$formname'});
 ${indent}\$self->TOPLEVEL(\$self->FORM->{'$formname'});
 ${indent}\$self->INSTANCE(\"$formname-\$instance\");
+${indent}\$self->CLASS_HIERARCHY(\$self->FORM->{'__WH'});
+${indent}\$self->WIDGET_HIERARCHY(\$self->FORM->{'__CH'});
 ${indent}\$__PACKAGE__::all_forms->{\$self->INSTANCE} = \$self->FORM;
 ${indent}return \$self;
 }";
@@ -348,12 +403,14 @@ $project->{'description'}
 
  use ${name};
 
- # Inherit the AUTOLOAD dynamic methods from ${first_form}
- *AUTOLOAD = \\\&$first_form\::AUTOLOAD;
-
- # Tell interpreter who we are inheriting from
- use vars qw( \@ISA ); \@ISA = qw( ${first_form} );
+ if (\$we_want_to_subclass_this_class) {
+   # Inherit the AUTOLOAD dynamic methods from ${first_form}
+   *AUTOLOAD = \\\&$first_form\::AUTOLOAD;
 
+   # Tell interpreter who we are inheriting from
+   use vars qw( \@ISA ); \@ISA = qw( ${first_form} );
+ }
+ 
  To construct the window object and show it call 
  
  Gtk->init;
@@ -393,17 +450,14 @@ sub write_UI {
         open UI,     ">".($proto->{'UI_filename'})    or 
             die "error $me - can't open file ".
                 "'$proto->{'UI_filename'}' for output";
-        $class->diag_print (4, "$indent- Writing UI source     to ".
+        $class->diag_print (2, "$indent- Writing UI   source to ".
             "$proto->{'UI_filename'} - in $me");
         if ($main::Glade_Perl_Generate_options->autoflush) {
             UI->autoflush(1);
         }
     }
-    $autosubs &&
-        $class->diag_print (2, "$indent- Automatically generated SUBS are ".
-            "'$autosubs' by $me");
-
     foreach $form (keys %$forms) {
+#        next if $form =~ /^__/;
         $class->diag_print(4, "$indent- Writing source for class $form");
         $permitted_stubs = '';
         foreach $handler (sort keys (%{$forms->{$form}{'_HANDLERS'}})) {
@@ -412,6 +466,9 @@ sub write_UI {
         # FIXME Now generate different source code for each user choice
         push @code, $class->perl_AUTOLOAD_top(
             $glade2perl, $proto, $form, $permitted_stubs)."\n";
+#print "Woring on form '$form'\n";
+#use Data::Dumper; print Dumper($forms);
+#print "'",join("'\n", @{$forms->{$form}{'UI_Strings'}}),"'\n";
         $UI_String = join("\n", @{$forms->{$form}{'UI_Strings'}});
         push @code, $UI_String;
         push @code, $class->perl_constructor_bottom($glade2perl, $form);
@@ -456,7 +513,7 @@ sub perl_AUTOLOAD_top {
     $module = $project->{'name'};
     # remove double spaces
     $isa_string =~ s/  / /g;
-return $class->perl_UI_preamble($module, $project, $proto, $name, undef).
+return $class->perl_preamble($module, $project, $proto, $name, undef).
 "BEGIN {
 ${indent}# Run-time utilities and vars
 ${indent}use Glade::PerlRun; 
@@ -466,6 +523,8 @@ ${indent}# Tell interpreter who we are inheriting from
 ${indent}\@ISA          = qw( $isa_string );
 }
 
+${indent}\$Glade::PerlRun::pixmaps_directory ||= '$glade2perl->{'glade_proto'}{'project'}{'pixmaps_directory'}';
+
 %fields = (
 ${indent}# These are the data fields that you can set/get using the dynamic
 ${indent}# calls provided by AUTOLOAD (and their initial values).
@@ -478,6 +537,8 @@ ${indent}VERSION  => '$project->{'version'}',
 ${indent}AUTHOR   => '$project->{'author'}',
 ${indent}DATE     => '$project->{'date'}',
 ${indent}INSTANCE => '$first_form',
+${indent}CLASS_HIERARCHY => undef,
+${indent}WIDGET_HIERARCHY => undef,
 );
 
 \%stubs = (
@@ -511,7 +572,7 @@ ${indent}${indent}__PACKAGE__->show_skeleton_message(
 ${indent}${indent}${indent}\$AUTOLOAD.\"\\n (AUTOLOADED by \".__PACKAGE__.\")\", 
 ${indent}${indent}${indent}\[\$self, \@_], 
 ${indent}${indent}${indent}__PACKAGE__, 
-${indent}${indent}${indent}'$project->{'logo_filename'}');
+${indent}${indent}${indent}'$project->{'logo'}');
 ${indent}${indent}
 ${indent}} else {
 ${indent}${indent}die \"Can't access method `\$name' in class \$type\\n\",
@@ -549,7 +610,7 @@ ${indent}while (defined \$__PACKAGE__::all_forms->{\"$name-\$instance\"}) {\$ins
 #===============================================================================
 sub write_SIGS {
     my ($class, $proto) = @_;
-    my $me = "$class->write_SUBCLASS";
+    my $me = "$class->write_SIGS";
     my ($permitted_stubs);
     my ($handler, $module, $form );
     my @code;
@@ -558,15 +619,15 @@ sub write_SIGS {
         open SIGS,     ">".($proto->{'SIGS_filename'})    or 
             die "error $me - can't open file ".
                 "'$proto->{'SIGS_filename'}' for output";
-        $class->diag_print (4, "$indent- Writing SIGS source     to ".
+        $class->diag_print (2, "$indent- Writing SIGS source to ".
             "$proto->{'SIGS_filename'} - in $me");
         if ($main::Glade_Perl_Generate_options->autoflush) {
             SIGS->autoflush(1);
         }
     }
-#    $autosubs &&
-#        $class->diag_print (2, "$indent- Automatically generated SUBS are ".
-#            "'$autosubs' by $me");
+    $autosubs &&
+        $class->diag_print (4, "$indent- Automatically generated SUBS are ".
+            "'$autosubs' by $me");
 
     $form = $first_form;
     $class->diag_print(4, "$indent- Writing SIGS for class $form");
@@ -577,54 +638,46 @@ sub write_SIGS {
             $glade2perl, $proto, $form, $permitted_stubs);
         push @code,  "
 #==============================================================================
-#=== Below are the signal handlers for '$form' UI construction class 
-#==============================================================================
-";
+#=== Below are the signal handlers for '$form' class 
+#==============================================================================";
 
         foreach $handler (sort keys (%{$forms->{$form}{'_HANDLERS'}})) {
             unless ($autosubs =~ / $handler /) {
-                push @code,  
-"sub $handler {
-${indent}my (\$class, \$data, \$object, \$instance, \$event) = \@_;
-${indent}my \$me = __PACKAGE__.\"->$handler\";
-${indent}# Get ref to hash of all widgets on our form
-${indent}my \$form = \$__PACKAGE__::all_forms->{\$instance};
-
-${indent}# REPLACE the line below with the actions to be taken when ".
-    "__PACKAGE__.\"->$handler.\" is called
-${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
-    "__PACKAGE__, '$glade2perl->{'logo_filename'}');
-
-} # End of sub $handler
-
-";
+                push @code, $class->perl_signal_handler($handler, 'SIGS');
             }
         }
         push @code, "\n\n\n\n\n\n\n\n";
     }
-    push @code, $class->perl_doc(
-        $glade2perl, $proto->{'APP_class'}, $first_form);
 
     print SIGS "#!/usr/bin/perl -w\n";
-        print SIGS "#
+    print SIGS "#
 # This is the (re)generated signal handler class 
 # You can cut and paste the skeleton signal handler subs from this file 
 # into the relevant classes in your application or its subclasses\n";
     print SIGS $class->warning;
     print SIGS join("\n", @code);
+    print SIGS $class->perl_doc(
+        $glade2perl, $proto->{'SIGS_class'}, $first_form);
     close SIGS; # flush buffers
 
     unless (-f $proto->{'APP_filename'}) {
         open SIGS,     ">".($proto->{'APP_filename'})    or 
             die "error $me - can't open file ".
                 "'$proto->{'APP_filename'}' for output";
-        $class->diag_print(2, 
+        $class->diag_print(4, 
             "${indent}- Creating app file $proto->{'APP_filename'}");
+        $class->diag_print (2, "$indent- Writing example App to ".
+            "$proto->{'APP_filename'} - in $me");
+        if ($main::Glade_Perl_Generate_options->autoflush) {
+            SIGS->autoflush(1);
+        }
         print SIGS "#!/usr/bin/perl -w\n";
         print SIGS "#
 # This is the basis of an application with signal handlers\n";
         print SIGS $class->warning('OKTOEDIT');
         print SIGS join("\n", @code);
+        print SIGS $class->perl_doc(
+            $glade2perl, $proto->{'APP_class'}, $first_form);
     }
 }
 
@@ -658,13 +711,13 @@ sub perl_SIGS_top {
     }
     # remove double spaces
 #    $isa_string =~ s/  / /g;
-return $class->perl_UI_preamble($module, $project, $proto, "$name").
+return $class->perl_preamble($module, $project, $proto, "$name").
 "BEGIN {
 $use_string
 }
 
 #===============================================================================
-#==== Below are signal handlers
+#=== Below are the default signal handlers for '$name' class
 #===============================================================================
 $about_string
 
@@ -685,22 +738,24 @@ sub toplevel_destroy { shift->get_toplevel->destroy }
 sub write_SUBCLASS {
     my ($class, $proto) = @_;
     my $me = "$class->write_SUBCLASS";
+    return if (-f $proto->{'SUBAPP_filename'});
     my @code;
     my ($permitted_stubs);
     my ($handler, $module, $form );
-#    unless (fileno SUBCLASS) {            # ie user has supplied a filename
-#        # Open SUBCLASS for output unless the filehandle is already open 
-#        open SUBCLASS,     ">".($proto->{'SUBCLASS_filename'})    or 
-#            die "error $me - can't open file ".
-#                "'$proto->{'SUBCLASS_filename'}' for output";
-#        $class->diag_print (4, "$indent- Writing SUBCLASS source     to ".
-#            "$proto->{'SUBCLASS_filename'} - in $me");
-#        if ($main::Glade_Perl_Generate_options->autoflush) {
-#            SUBCLASS->autoflush(1);
-#        }
-#    }
+    unless (fileno SUBCLASS) {            # ie user has supplied a filename
+        open SUBCLASS,     ">".($proto->{'SUBAPP_filename'})    or 
+            die "error $me - can't open file ".
+                "'$proto->{'SUBAPP_filename'}' for output";
+        $class->diag_print(4, 
+            "${indent}- Creating app subclass file $proto->{'SUBAPP_filename'}");
+        $class->diag_print (2, "$indent- Writing Subclass    to ".
+            "$proto->{'SUBCLASS_filename'} - in $me");
+        if ($main::Glade_Perl_Generate_options->autoflush) {
+            SUBCLASS->autoflush(1);
+        }
+    }
 #    $autosubs &&
-#        $class->diag_print (2, "$indent- Automatically generated SUBS are ".
+#        $class->diag_print (4, "$indent- Automatically generated SUBS are ".
 #            "'$autosubs' by $me");
 
     $form = $first_form;
@@ -714,29 +769,12 @@ sub write_SUBCLASS {
             $glade2perl, $proto, $form, $permitted_stubs);
         push @code, "
 #==============================================================================
-#=== Below are overloaded signal handlers for '$form' class 
-#==============================================================================
-";
+#=== Below are (overloaded) signal handlers for '$form' class 
+#==============================================================================";
 
         foreach $handler (sort keys (%{$forms->{$form}{'_HANDLERS'}})) {
             unless ($autosubs =~ / $handler /) {
-                push @code, 
-"sub $handler {
-${indent}my (\$class, \$data, \$object, \$instance, \$event) = \@_;
-
-${indent}my \$me = __PACKAGE__.\"->on_button2_clicked\";
-${indent}# Get ref to hash of all widgets on our form
-${indent}my \$form = \$__PACKAGE__::all_forms->{\$instance};
-
-${indent}# REPLACE the line below with the actions to be taken when ".
-"__PACKAGE__.\"->on_button2_clicked.\" is called
-#${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
-    "__PACKAGE__, '$glade2perl->{'logo_filename'}');
-${indent}shift->SUPER::$handler(\@_);
-
-} # End of sub $handler
-
-";
+                push @code, $class->perl_signal_handler($handler, 'SUBCLASS');
             }
         }
         push @code, "\n\n\n\n\n\n\n\n";
@@ -744,23 +782,11 @@ ${indent}shift->SUPER::$handler(\@_);
     push @code, $class->perl_doc(
         $glade2perl, $proto->{'SUBAPP_class'}, "Sub".$first_form);
 
-#    print SUBCLASS "#!/usr/bin/perl -w\n";
-#    print SUBCLASS $class->warning;
-#    print SUBCLASS join("\n", @code);
-#    close SUBCLASS; # flush buffers
-    
-    unless (-f $proto->{'SUBAPP_filename'}) {
-        open SUBCLASS,     ">".($proto->{'SUBAPP_filename'})    or 
-            die "error $me - can't open file ".
-                "'$proto->{'SUBAPP_filename'}' for output";
-        $class->diag_print(2, 
-            "${indent}- Creating app subclass file $proto->{'SUBAPP_filename'}");
-        print SUBCLASS "#!/usr/bin/perl -w\n";
-        print SUBCLASS "#
+    print SUBCLASS "#!/usr/bin/perl -w\n";
+    print SUBCLASS "#
 # This is an example of a subclass of the generated application\n";
-        print SUBCLASS $class->warning('OKTOEDIT');
-        print SUBCLASS join("\n", @code);
-    }
+    print SUBCLASS $class->warning('OKTOEDIT');
+    print SUBCLASS join("\n", @code);
 }
 
 sub perl_SUBCLASS_top {
@@ -791,7 +817,7 @@ sub perl_SUBCLASS_top {
     }
     # remove double spaces
     $isa_string =~ s/  / /g;
-return $class->perl_UI_preamble($module, $project, $proto, "Sub$name").
+return $class->perl_preamble($module, $project, $proto, "Sub$name").
 "BEGIN {
 ${indent}use vars    qw( 
 ${indent}                 \@ISA
@@ -849,7 +875,7 @@ ${indent}Gtk->main;
 ${indent}return \$window;
 }
 #===============================================================================
-#==== Below are any overloaded signal handlers
+#=== Below are (overloaded) default signal handlers for '$name' class 
 #===============================================================================
 $about_string
 
@@ -869,59 +895,58 @@ sub toplevel_destroy { shift->get_toplevel->destroy }
 #===============================================================================
 sub write_LIBGLADE {
     my ($class, $proto) = @_;
-    my $me = "$class->write_SUBCLASS";
+    my $me = "$class->write_LIBGLADE";
+    my @code;
     my ($permitted_stubs);
     my ($handler, $module, $form );
+    return if -f $proto->{'LIBGLADE_filename'};
     unless (fileno LIBGLADE) {            # ie user has supplied a filename
         # Open LIBGLADE for output unless the filehandle is already open 
         open LIBGLADE,     ">".($proto->{'LIBGLADE_filename'})    or 
             die "error $me - can't open file ".
                 "'$proto->{'LIBGLADE_filename'}' for output";
-        $class->diag_print (4, "$indent- Writing LIBGLADE source     to ".
-            "$proto->{'LIBGLADE_filename'} - in $me");
-        if ($main::Glade_Perl_Generate_options->autoflush) {
-            LIBGLADE->autoflush(1);
-        }
     }
     $autosubs &&
-        $class->diag_print (2, "$indent- Automatically generated SUBS are ".
+        $class->diag_print (4, "$indent- Automatically generated SUBS are ".
             "'$autosubs' by $me");
 
-    print LIBGLADE "#!/usr/bin/perl -w\n";
-    print LIBGLADE $class->warning;
     $form = $first_form;
     $class->diag_print(4, "$indent- Writing LIBGLADE for class $form");
     $permitted_stubs = '';
     # FIXME Now generate different source code for each user choice
-    print LIBGLADE $class->perl_LIBGLADE_top(
+    push @code, $class->perl_LIBGLADE_top(
         $glade2perl, $proto, $form, $permitted_stubs)."\n";
-#    print LIBGLADE $class->perl_LIBGLADE_AUTOLOAD_new_bottom($project, $form);
+#    push @code, $class->perl_LIBGLADE_AUTOLOAD_new_bottom($project, $form);
     foreach $form (keys %$forms) {
-    print LIBGLADE "
+    push @code, "
 #==============================================================================
-#=== Below are the signal handlers for '$form' UI construction class 
+#=== Below are the signal handlers for '$form' UI
 #==============================================================================";
 
         foreach $handler (sort keys (%{$forms->{$form}{'_HANDLERS'}})) {
             unless ($autosubs =~ / $handler /) {
-                print LIBGLADE "
-sub $handler {
-${indent}my (\$class, \$data, \$event) = \@_;
-${indent}my \$me = __PACKAGE__.\"->$handler\";
-
-${indent}# REPLACE the line below with the actions to be taken when ".
-    "__PACKAGE__.\"->$handler.\" is called
-${indent}__PACKAGE__->show_skeleton_message(\$me, \\\@_, ".
-    "__PACKAGE__, '$glade2perl->{'logo_filename'}');
-
-} # End of sub $handler
-";
+                push @code, $class->perl_signal_handler($handler, 'LIBGLADE');
             }
         }
     }
-    print LIBGLADE $class->perl_doc(
+    push @code, $class->perl_doc(
         $glade2perl, $proto->{'LIBGLADE_class'}, $proto->{'LIBGLADE_class'});
 
+    open LIBGLADE,     ">".($proto->{'LIBGLADE_filename'})    or 
+        die "error $me - can't open file ".
+            "'$proto->{'LIBGLADE_filename'}' for output";
+    $class->diag_print(2, 
+        "${indent}- Creating libglade app file $proto->{'LIBGLADE_filename'}");
+    $class->diag_print (2, "$indent- Writing libglade app source     to ".
+        "$proto->{'LIBGLADE_filename'} - in $me");
+    LIBGLADE->autoflush(1) if $main::Glade_Perl_Generate_options->autoflush;
+
+    print LIBGLADE "#!/usr/bin/perl -w\n";
+    print LIBGLADE "#
+# This is the basis of a LIBGLADE application with signal handlers\n";
+    print LIBGLADE $class->warning('OKTOEDIT');
+    print LIBGLADE join("\n", @code);
+    close LIBGLADE;
 }
 
 sub perl_LIBGLADE_top {
@@ -956,7 +981,7 @@ ${indent}Gtk::GladeXML->init();";
     $module = $project->{'name'};
     # remove double spaces
     $isa_string =~ s/  / /g;
-return $class->perl_UI_preamble($module, $project, $proto, $project->{'LIBGLADE_class'}, undef).
+return $class->perl_preamble($module, $project, $proto, $project->{'LIBGLADE_class'}, undef).
 "BEGIN {
 ${indent}use vars    qw( 
 ${indent}                 \@ISA
@@ -968,6 +993,8 @@ ${indent}# Tell interpreter who we are inheriting from
 ${indent}\@ISA      = qw( Glade::PerlRun Gtk::GladeXML);
 }
 
+${indent}\$Glade::PerlRun::pixmaps_directory ||= '$glade2perl->{'glade_proto'}{'project'}{'pixmaps_directory'}';
+
 \%fields = (
 # Insert any extra data access methods that you want to add to 
 #   our inherited super-constructor (or overload)
@@ -984,8 +1011,8 @@ ${indent}# Allow indirect constructor so that we can call eg.
 ${indent}#   \$window1 = BusFrame->new; \$window2 = \$window1->new;
 ${indent}my \$class = ref(\$that) || \$that;
 
-${indent}# Call our super-class constructor to get an object and reconsecrate it
-${indent}my \$self = bless new Gtk::GladeXML('$project->{'glade_filename'}'), \$class;
+${indent}# Call Gtk::GladeXML to get an object and reconsecrate it
+${indent}my \$self = bless new Gtk::GladeXML('$project->{'glade_filename'}', '$first_form'), \$class;
 
 ${indent}# Add our own data access methods to the inherited constructor
 ${indent}my(\$element);
@@ -1006,7 +1033,7 @@ ${indent}Gtk->main;
 ${indent}return \$window;
 }
 #===============================================================================
-#==== Below are signal handlers
+#=== Below are the default signal handlers for '$name' class 
 #===============================================================================
 $about_string
 
@@ -1046,7 +1073,7 @@ sub perl_Closure_top {
     $module = $project->{'name'};
     # remove double spaces
     $isa_string =~ s/  / /g;
-return $class->perl_UI_preamble($module, $project, $proto, $name, undef).
+return $class->perl_preamble($module, $project, $proto, $name, undef).
 "BEGIN {
 ${indent}# Run-time utilities and vars
 ${indent}use Glade::PerlRun; 
@@ -1068,6 +1095,8 @@ ${indent}VERSION  => '$project->{'version'}',
 ${indent}AUTHOR   => '$project->{'author'}',
 ${indent}DATE     => '$project->{'date'}',
 ${indent}INSTANCE => '$first_form',
+${indent}CLASS_HIERARCHY => undef,
+${indent}WIDGET_HIERARCHY => undef,
 );
 
 \%stubs = (
@@ -1100,7 +1129,7 @@ ${indent}${indent}__PACKAGE__->show_skeleton_message(
 ${indent}${indent}${indent}\$AUTOLOAD.\"\\n (AUTOLOADED by \".__PACKAGE__.\")\", 
 ${indent}${indent}${indent}\[\$self, \@_], 
 ${indent}${indent}${indent}__PACKAGE__, 
-${indent}${indent}${indent}'$project->{'logo_filename'}');
+${indent}${indent}${indent}'$project->{'logo'}');
 ${indent}${indent}
 ${indent}} else {
 ${indent}${indent}die \"Can't access method `\$name' in class \$type\";
